# RelevantQGPTSeeds

This is a plural of RelevantQGPTSeed.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_schema** | [**EmbeddedModelSchema**](EmbeddedModelSchema.md) |  | [optional] 
**iterable** | [**List[RelevantQGPTSeed]**](RelevantQGPTSeed.md) |  | 

## Example

```python
from openapi_client.models.relevant_qgpt_seeds import RelevantQGPTSeeds

# TODO update the JSON string below
json = "{}"
# create an instance of RelevantQGPTSeeds from a JSON string
relevant_qgpt_seeds_instance = RelevantQGPTSeeds.from_json(json)
# print the JSON string representation of the object
print RelevantQGPTSeeds.to_json()

# convert the object into a dict
relevant_qgpt_seeds_dict = relevant_qgpt_seeds_instance.to_dict()
# create an instance of RelevantQGPTSeeds from a dict
relevant_qgpt_seeds_form_dict = relevant_qgpt_seeds.from_dict(relevant_qgpt_seeds_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


